# binaryPy

## 工具介绍

将python代码加密为so或pyd（支持项目文件/单个文件加密）

Git仓库地址: https://github.com/xqlip/binaryPy.git

python: 3.6 +
## 安装

    pip install binaryPy

## 使用方法

    binaryPy -i "project dir/ file " [-o output dir] [-I ignore files]